@@ -2,7 +2,7 @@
 
 import pytest
 from copy import copy
-from collections.abc import Mapping
+from collections.abc import Mapping, Iterable
 from contextlib2 import nullcontext
 from functools import partial
 from unittest.mock import Mock
@@ -159,7 +159,6 @@ class Namespace(Mapping):
     def eval(self, *src, keys=False, defer=False):
         """
         Evaluate the given expression within this namespace.
-        this object.
 
         Arguments:
             src (str,list,dict):
@@ -248,9 +247,13 @@ class Namespace(Mapping):
         Arguments:
             src (str): A snippet of python code to execute.
 
-            get (str, collections.abc.Callable):
+            get (str, collections.abc.Iterable, collections.abc.Callable):
                 If string: The name of a variable defined in the given snippet 
                 to look up and pass on to the caller.
+
+                If iterable: The names of variables defined in the given 
+                snippet to look up and return to the caller.  The return value 
+                will be a tuple with the same length as the given iterable.
                 
                 If callable: The given function will be passed a read-only 
                 dictionary containing all the names defined in the given 
@@ -271,7 +274,7 @@ class Namespace(Mapping):
             Basic usage::
 
                 >>> with_a = Namespace(a=1)
-                >>> with_b = ns1.exec('b = a + 1')
+                >>> with_b = with_a.exec('b = a + 1')
                 >>> with_a
                 Namespace({'a': 1})
                 >>> with_b
@@ -315,6 +318,8 @@ class Namespace(Mapping):
             return fork
         elif callable(get):
             return get(fork)
+        elif isinstance(get, Iterable) and not isinstance(get, str):
+            return tuple(fork[x] for x in get)
         else:
             return fork[get]
 
@@ -387,7 +392,7 @@ class Namespace(Mapping):
                 ...     pass
                 ...
                 >>> with_err = Namespace(MyError=MyError)
-                >>> p = {'type': 'MyError', 'message': r'\\d+'}
+                >>> p = {'type': 'MyError', 'pattern': r'\\d+'}
                 >>> with with_err.error(p):
                 ...    raise MyError('404')
 
@@ -467,14 +472,12 @@ class ExpectError:
         self.exc_info = self.raises_cm.__enter__()
 
     def __exit__(self, *args):
-        __tracebackhide__ = True
-
         if self.raises_cm.__exit__(*args):
             ns = self.namespace
             exc = self.exc_info.value
 
             for msg in self.messages:
-                assert msg in str(exc)
+                assert msg in str(exc), f'{msg!r} not in {str(exc)!r}'
 
             for pat in self.patterns:
                 self.exc_info.match(pat)
