@@ -386,6 +386,18 @@ def test_eval_err(globals, args, kwargs, error):
                 {'get': 'b'},
                 lambda f: f('b = a + 1'),
                 2,
+            ), (
+                {'a': 1},
+                [],
+                {'get': ('a', 'b')},
+                lambda f: f('b = a + 1'),
+                (1, 2),
+            ), (
+                {'a': 1},
+                [],
+                {'get': ['a', 'b']},
+                lambda f: f('b = a + 1'),
+                (1, 2),
             ), (
                 {'a': 1},
                 [],
